 /*
 * FILE --- lqr_ex.cc 
 *
 * PURPOSE --- To rpovide an example use of the class for 4'th
 * order Runge-Kutta simulation, RK4_SIM.
 * Implements the man function of a class for performing a simulation of
 * a simple vehicle with point mass dynamics.
 *
 */

// Include Files

#include <stdlib.h>
#include <stdio.h>
#include <math.h>

#include "veh_sim_lqr.hh"

void main(void) 
{
  
  double Ts = 0.01;             // Sampling time
  double y[3] = {-0.9*45.0,45.0,0.0};  // Initial conditions    
  double t0 = 0.0;              // Initial time 
  double tmax = 200.0;              // Total Simulation period
  
  // State feedback gains --- Note that this is not Linear Quadratic Regulator
  double my_gains[3] = {-100.0,-50.0,-1.0};

  // # of simulation steps to be performed by the RK4 algorith
  // in one sampling interval
  int sim_per_cycle = 5;  

  // Create the vehicle object
  VEH_SIM_LQR my_vehicle(Ts,sim_per_cycle,t0,(double *)y);

  FILE *fp;  // To save data

  if (!(fp = fopen("veh_lqr_out.dat","w"))) {
    printf("Can't open file.\n");
    exit(1);
  }


  my_vehicle.lqr_ctrl->set_gains(my_gains);

  /* Simulate For tmax seconds. */
  while(my_vehicle.current_time < tmax) 
    {
      my_vehicle.simulate();    
      fprintf(fp,"%f %f %f %f %f %f %f\n", my_vehicle.current_time,
	      my_vehicle.plant_state[0], my_vehicle.plant_state[1],
	      my_vehicle.plant_state[2], my_vehicle.ctrl_input[0],
	      my_vehicle.ctrl_input[1], my_vehicle.ctrl_input[2]);
    }

  fclose(fp);
}
